
/* module.c: Sony PH Key Driver.
 *
 * Copyright 2016 Sony Corporation.
 * Author: Sony Corporation.
 *
 * This package is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef __PH_KEY__PH_KEY_H__INCLUDED__
#define __PH_KEY__PH_KEY_H__INCLUDED__


#define PHKEY_AKEYDATA(min, max, code)	{ min, (max)-(min), code }

	/* フラグ */
	enum {
		PHKEY_FLAG_LOW				=	0 << 0,						/* ローアクティブ */
		PHKEY_FLAG_HIGH				=	1 << 0,						/* ハイアクティブ */
		PHKEY_FLAG_POLLING			=	1 << 1,						/* ポーリング     */
		PHKEY_FLAG_WAKEUP			=	1 << 2						/* ウェイクアップ */
	} ;

	/* AD キーデータ */
	struct phkey_akeydata {
		u16							min ;							/* 閾値の最小値 */
		u16							range ;							/* 閾値の範囲   */
		u16							key_code ;						/* キーコード   */
	} ;

	/* AD キー情報 */
	struct phkey_akeyinfo {
		u16							flags ;							/* フラグ          */
		u16							eint_num ;						/* EINT 番号       */
		u16							channel ;						/* チャンネル      */
		u16							count ;							/* AD キーデータ数 */
		struct phkey_akeydata		const *p_data ;					/* AD キーデータ   */
	} ;

	/* GPIO キー情報 */
	struct phkey_gkeyinfo {
		u16							flags ;							/* フラグ     */
		u16							eint_num ;						/* EINT 番号  */
		u16							port ;							/* ポート番号 */
		u16							key_code ;						/* キーコード */
	} ;

	/* 構成 */
	struct phkey_config {
		uint						count ;							/* 仮想キーコード数 */
		u16							const *p_key_code ;				/* 仮想キーコード   */

		struct {
			uint					count ;							/* AD キー情報数    */
			struct phkey_akeyinfo	const *p_info ;					/* AD キー情報      */
		} akey ;

		struct {
			uint					count ;							/* GPIO キー情報数  */
			struct phkey_gkeyinfo	const *p_info ;					/* GPIO キー情報    */
		} gkey ;
	} ;


#endif/*__PH_KEY__PH_KEY_H__INCLUDED__*/
